<template>
  <a-spin :spinning="confirmLoading">
    <j-form-container :disabled="formDisabled">
      <a-form-model
        ref="form"
        :model="model"
        :rules="validatorRules"
        slot="detail"
      >
        <a-row>
          <a-col :span="24">
            <a-form-model-item
              label="单据名称"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="name"
            >
              <j-dict-select-tag
                placeholder="请选择单据名称"
                :triggerChange="true"
                dictCode="sys_file_name"
                v-model="model.name"
              />
            </a-form-model-item>
          </a-col>

        </a-row>
        <a-row>
          <a-col :span="24">
            <a-form-model-item
              label="单据编码"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="num"
            >
              <a-input
                v-model="model.num"
                placeholder="请输入单据编码"
              ></a-input>
            </a-form-model-item>
          </a-col>
          <!-- <a-col :span="24">
            <a-form-model-item
              label="单据名称"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="name"
            >
              <a-input
                v-model="model.name"
                placeholder="请输入单据名称"
              ></a-input>
            </a-form-model-item>
          </a-col> -->
        </a-row>

        <a-row>
          <a-col :span="24">
            <a-form-model-item
              label="版本"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="version"
            >
              <a-input
                v-model="model.version"
                placeholder="请输入版本号"
                :disabled=true
              ></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row>

          <a-col
            v-if=" model.isRevise == true"
            :span="24"
          >
            <a-form-model-item
              label="历史版本"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="version"
            >
              <a-input
                v-model="model.historyVersion"
                placeholder="请输入历史版本"
                :disabled=true
              ></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>

<script>
import { httpAction, getAction, requestPut } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import pick from 'lodash.pick'
import JMultiSelectTag from '@/components/dict/JMultiSelectTag'

export default {
  name: 'SysFileNameForm',
  components: { JMultiSelectTag },
  props: {
    //表单禁用
    disabled: {
      type: Boolean,
      default: false,
      required: false,
    },
    // enterpriseId: {
    //   type: String,
    //   default: '',
    //   required: false,
    // },
    // version: {
    //   type: Number,
    //   required: false,
    // },
  },
  data() {
    return {
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      validatorRules: {
        name: [
          { required: true, message: '请选择单据名称!' },
        ],
        num: [
          { required: true, message: '请输入单据编码!' },
        ],
        version: [
          { required: true, message: '请输入版本号!' },
        ],
      },
      url: {
        add: '/eam/sysFileName/add',
        edit: '/eam/sysFileName/edit',
        revise: '/eam/sysFileName/revise',
        getReviseVersion: "/eam/sysFileName/getReviseVersion",
      },
    }
  },
  computed: {
    formDisabled() {
      return this.disabled
    },
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model))
  },
  methods: {
    add() {
      this.edit(this.modelDefault)
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
      this.model.isRevise = false;
      //修改时
      if (record.id) {

        //新增时
      } else {
        this.model.version = '1.0'
        this.model.versionStatus = '1'
      }
    },

    //升版
    revise(record) {
      let that = this;
      that.visible = true;
      that.model = Object.assign({}, record)
      that.model.isRevise = true;
      that.model.historyVersion = record.version
      that.model.versionStatus = '1'
      requestPut(that.url.getReviseVersion, record).then((res) => {
        if (res.success) {
          that.model.version = res.result;
        }
      })
    },

    submitForm() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            if (this.model.isRevise) {
              httpurl += this.url.revise
              method = 'post'
            } else {
              httpurl += this.url.edit
              method = 'put'
            }
          }
          httpAction(httpurl, this.model, method)
            .then((res) => {
              if (res.success) {
                that.$message.success(res.message)
                that.$emit('ok')
              } else {
                that.$message.warning(res.message)
              }
            })
            .finally(() => {
              that.confirmLoading = false
            })
        }
      })
    },
  },
}
</script>